@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2022, OARC, Inc.
+ * Copyright (c) 2018-2023, OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -397,8 +397,10 @@ int cryptopan_filter(const char* descr, iaddr* from, iaddr* to, uint8_t proto, u
 #ifdef USE_OPENSSL
     for (;;) {
         if (only_clients && sport == dns_port) {
-            from = 0;
-            break;
+            if (sport != dport) {
+                from = 0;
+                break;
+            }
         }
         if (only_servers && sport != dns_port) {
             from = 0;
@@ -433,8 +435,10 @@ int cryptopan_filter(const char* descr, iaddr* from, iaddr* to, uint8_t proto, u
 
     for (;;) {
         if (only_clients && dport == dns_port) {
-            to = 0;
-            break;
+            if (dport != sport) {
+                to = 0;
+                break;
+            }
         }
         if (only_servers && dport != dns_port) {
             to = 0;
